import java.io.IOException;

import org.apache.lucene.analysis.standard.StandardAnalyzer;
import org.apache.lucene.document.Document;
import org.apache.lucene.document.TextField;
import org.apache.lucene.document.StringField;
import org.apache.lucene.index.DirectoryReader;
import org.apache.lucene.index.IndexReader;
import org.apache.lucene.index.IndexWriter;
import org.apache.lucene.index.IndexWriterConfig;
import org.apache.lucene.queryparser.classic.ParseException;
import org.apache.lucene.queryparser.classic.QueryParser;
import org.apache.lucene.search.IndexSearcher;
import org.apache.lucene.search.Query;
import org.apache.lucene.search.ScoreDoc;
import org.apache.lucene.search.TopScoreDocCollector;
import org.apache.lucene.store.Directory;
import org.apache.lucene.store.RAMDirectory;

public class HelloLucene {

	public static void main(String[] args) throws ParseException, IOException {
		int id=0;
		// specify analyzer for indexing/searching
		StandardAnalyzer analyzer = new StandardAnalyzer();
		
		// create index
		Directory index = new RAMDirectory();
		IndexWriterConfig config = new IndexWriterConfig(analyzer);

		IndexWriter w = null;

		w = new IndexWriter(index, config);
		addDoc(w, "Lucene in Action", ++id);
		addDoc(w, "Lucene for Dummies", ++id);
		addDoc(w, "Managing Gigabytes", ++id);
		addDoc(w, "The Art of Computer Science", ++id);
		w.close();
		
		String querystr = "lucene";
		// Use the same analyzer for both indexing and searching
		QueryParser parser = new QueryParser("title", analyzer);
		Query q = null;
		q = parser.parse(querystr);

		// store the top 10 results when searching
		int hitsPerPage = 10;
		IndexReader reader = null;
		TopScoreDocCollector collector = null;
		IndexSearcher searcher = null;
		// search in the index
		reader = DirectoryReader.open(index);
		searcher = new IndexSearcher(reader);
		collector = TopScoreDocCollector.create(hitsPerPage);
		// search for the specified query
		searcher.search(q, collector);
		ScoreDoc[] hits = collector.topDocs().scoreDocs;

		// display the results
		System.out.println("Found " + hits.length + " hits.");
		for (int i = 0; i < hits.length; ++i) {
			int docId = hits[i].doc;
			Document d;
	
			d = searcher.doc(docId);
	
			System.out.println((i + 1) + ". " + d.get("title"));
		}
		
		// close the index reader	
		reader.close();

	}
	
	// create the addDoc() function
	private static void addDoc(IndexWriter w, String title, int id) throws IOException {
		Document doc = new Document();
		doc.add(new StringField("id", Integer.toString(id), StringField.Store.YES));
		doc.add(new TextField("title", title, TextField.Store.YES));
		w.addDocument(doc);
	}


}
